import axios from 'axios'
import { Notification, MessageBox, Message } from 'element-ui'
import store from '@/store'
import { getToken } from '@/utils/auth'
import errorCode from '@/utils/errorCode'
import { tansParams } from "@/utils/ruoyi";

axios.defaults.headers['Content-Type'] = 'application/json;charset=utf-8'
//




axios.defaults.headers['accountName'] = 'guest'
// 创建axios实例
const service = axios.create({
  // axios中请求配置有baseURL选项，表示请求URL公共部分
  baseURL: process.env.VUE_APP_BASE_API,
  // 超时
  timeout: 50000
})

// request拦截器
service.interceptors.request.use(config => {
  // 是否需要设置 token
  const isToken = (config.headers || {}).isToken === false
  // console.log(config,14)
  // if(config.url == '/sendSms/list'){
  //   config.baseURL = ""
  // }
  // console.log(config,15)
  if (getToken() && !isToken) {
    config.headers['Authorization'] = 'Bearer ' + getToken() // 让每个请求携带自定义token 请根据实际情况自行修改
  }
  // get请求映射params参数
  if (config.method === 'get' && config.params) {
    let url = config.url + '?';
    for (const propName of Object.keys(config.params)) {
      const value = config.params[propName];
      var part = encodeURIComponent(propName) + "=";
      if (value !== null && typeof(value) !== "undefined") {
        if (typeof value === 'object') {
          for (const key of Object.keys(value)) {
            let params = propName + '[' + key + ']';
            var subPart = encodeURIComponent(params) + "=";
            url += subPart + encodeURIComponent(value[key]) + "&";
          }
        } else {
          url += part + encodeURIComponent(value) + "&";
        }
      }
    }
    url = url.slice(0, -1);
    config.params = {};
    config.url = url;
  }
  // console.log(config,456)
  return  config
}, error => {
    console.log(error)
    Promise.reject(error)
})

// 响应拦截器
service.interceptors.response.use(res => {
    // 未设置状态码则默认成功状态
    const code = res.data.code || 200;
    // 获取错误信息
    const msg = errorCode[code] || res.data.msg || errorCode['default']
    if (code === 401) {
      MessageBox.confirm('登录状态已过期，您可以继续留在该页面，或者重新登录', '系统提示', {
          confirmButtonText: '重新登录',
          cancelButtonText: '取消',
          type: 'warning'
        }
      ).then(() => {
        store.dispatch('LogOut').then(() => {
          location.href = '/index';
        })
      })
    } else if (code === 500) {
      // Message({
      //   message: msg,
      //   type: 'error'
      // })
      if(res.data.msg == '当前填写的户籍地址和居住地址均不属于对应辖区'){
        return res.data
      }else{
       Message({
         message: msg,
         type: 'error'
       })
        return Promise.reject(new Error(msg))
      }
    } else if (code !== 200) {
      if(res.data.msg == '当前填写的户籍地址和居住地址均不属于对应辖区'){
       return res.data
      }else{
         // return res.data
      Message({
        message: msg,
        type: 'error'
      })
       return Promise.reject('error')
      }
    // return res.data
    } else {
      return res.data
    }
  },
  error => {
    console.log('err' + error)
    let { message } = error;
    if (message == "Network Error") {
      message = "后端接口连接异常";
    }
    else if (message.includes("timeout")) {
      message = "系统接口请求超时";
    }
    else if (message.includes("Request failed with status code")) {
      message = "系统接口" + message.substr(message.length - 3) + "异常";
    }
    else{
      error  = message
    }
    Message({
      message: message,
      type: 'error',
      duration: 5 * 1000
    })
    return Promise.reject(error)
  }
)

// 通用下载方法
export function download(url, params, filename) {
  return service.post(url, params, {
    // transformRequest: [(params) => {
    //   return tansParams(params)
    // }],
    params,
    headers: {
        'Content-Type': 'application/json'
    },
    responseType: 'blob'
  }).then((data) => {
    let reader = new FileReader()
    const content = data
    const blob = new Blob([content])
    reader.addEventListener("loadend", () => {
        // 将会打印json格式
        if(data.type=='application/json'){
          var res=JSON.parse(reader.result)
          if(res.code===500){
            Message({
              message: res.msg,
              type: 'error'
            })
          }
        }else{

          if ('download' in document.createElement('a')) {
            const elink = document.createElement('a')
            elink.download = filename
            elink.style.display = 'none'
            elink.href = URL.createObjectURL(blob)
            document.body.appendChild(elink)
            elink.click()
            URL.revokeObjectURL(elink.href)
            document.body.removeChild(elink)
          } else {
            navigator.msSaveBlob(blob, filename)
          }
        }
    })
     reader.readAsText(data, "utf-8")





  }).catch((r) => {
    console.error(r)
  })
}

export default service
